@@ -84,7 +84,7 @@
 #define KCMUTILSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILSCORE_NO_DEPRECATED
-#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57100
 #endif
 #ifdef KCMUTILSCORE_NO_DEPRECATED_WARNINGS
 #  define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x57100
 #  endif
 #endif
 
